+{
   entry => <<'ENTRY', # for DUCET v6.0.0
1EB9      ; [.1600.0020.0002.1EB9] # LATIN SMALL LETTER E WITH DOT BELOW
0065 0323 ; [.1600.0020.0002.1EB9] # LATIN SMALL LETTER E WITH DOT BELOW
1EB8      ; [.1600.0020.0008.1EB8] # LATIN CAPITAL LETTER E WITH DOT BELOW
0045 0323 ; [.1600.0020.0008.1EB8] # LATIN CAPITAL LETTER E WITH DOT BELOW
1EC7      ; [.1600.0020.0002.1EB9][.0000.003C.0002.0302] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
1EC6      ; [.1600.0020.0008.1EB8][.0000.003C.0002.0302] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
0067 0062 ; [.1645.0020.0002.0067] # <LATIN SMALL LETTER G, LATIN SMALL LETTER B>
0047 0062 ; [.1645.0020.0007.0047] # <LATIN CAPITAL LETTER G, LATIN SMALL LETTER B>
0047 0042 ; [.1645.0020.0008.0047] # <LATIN CAPITAL LETTER G, LATIN CAPITAL LETTER B>
1ECD      ; [.1725.0020.0002.1ECD] # LATIN SMALL LETTER O WITH DOT BELOW
006F 0323 ; [.1725.0020.0002.1ECD] # LATIN SMALL LETTER O WITH DOT BELOW
1ECC      ; [.1725.0020.0008.1ECC] # LATIN CAPITAL LETTER O WITH DOT BELOW
004F 0323 ; [.1725.0020.0008.1ECC] # LATIN CAPITAL LETTER O WITH DOT BELOW
1ED9      ; [.1725.0020.0002.1ECD][.0000.003C.0002.0302] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW
1ED8      ; [.1725.0020.0008.1ECC][.0000.003C.0002.0302] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW
1EE3      ; [.1725.0020.0002.1ECD][.0000.0068.0002.031B] # LATIN SMALL LETTER O WITH HORN AND DOT BELOW
1EE2      ; [.1725.0020.0008.1ECC][.0000.0068.0002.031B] # LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW
1E63      ; [.17A7.0020.0002.1E63] # LATIN SMALL LETTER S WITH DOT BELOW
0073 0323 ; [.17A7.0020.0002.1E63] # LATIN SMALL LETTER S WITH DOT BELOW
1E62      ; [.17A7.0020.0008.1E62] # LATIN CAPITAL LETTER S WITH DOT BELOW
0053 0323 ; [.17A7.0020.0008.1E62] # LATIN CAPITAL LETTER S WITH DOT BELOW
ENTRY
};
